==> mediawiki-1.25.3-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/Renameuser/Renameuser.alias.php <==
<?php
/**
 * Aliases for Special:Renameuser
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Renameuser' => array( 'RenameUser' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Renameuser' => array( 'إعادة_تسمية_مستخدم' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Renameuser' => array( 'سمّى_تانى_يوزر' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'Renameuser' => array( 'সদস্য_পুনৰ্নামকৰণ' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'Renameuser' => array( 'Переименовать_участника' ),
);

/** Bashkir (башҡортса) */
$specialPageAliases['ba'] = array(
	'Renameuser' => array( 'RenameUser' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'Renameuser' => array( 'Преименуване' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'Renameuser' => array( 'Ganti_ngaran_pamakai' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'Renameuser' => array( 'AdenevelImplijer' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'Renameuser' => array( 'PreimenovanjeKorisnika' ),
);

/** Catalan (català) */
$specialPageAliases['ca'] = array(
	'Renameuser' => array( 'Reanomena_usuari' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Renameuser' => array( 'Декъашхочун_цӀе_хийца' ),
);

/** Czech (čeština) */
$specialPageAliases['cs'] = array(
	'Renameuser' => array( 'Přejmenovat_uživatele' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Renameuser' => array( 'Benutzer_umbenennen' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Renameuser' => array( 'NamedayışéKarberi' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'Renameuser' => array( 'Wužywarja pśemjeniś' ),
);

/** Divehi (ދިވެހިބަސް) */
$specialPageAliases['dv'] = array(
	'Renameuser' => array( 'މެމްބަރުގެ_ނަން_ބަދަލު_ކުރައްވާ' ),
);

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = array(
	'Renameuser' => array( 'ΜετονομασίαΧρήστη' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Renameuser' => array( 'Alinomigi_uzanton' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Renameuser' => array( 'RenombrarUsuario', 'Renombrar_usuario', 'Cambiar_el_nombre_de_usuario' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Renameuser' => array( 'Kasutaja_ümbernimetamine' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Renameuser' => array( 'تغییر_نام_کاربر' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Renameuser' => array( 'Käyttäjätunnusten_nimeäminen' ),
);

/** French (français) */
$specialPageAliases['fr'] = array(
	'Renameuser' => array( 'Renommer_utilisateur', 'RenommerUtilisateur' ),
);

/** Franco-Provençal (arpetan) */
$specialPageAliases['frp'] = array(
	'Renameuser' => array( 'Renomar_l\'usanciér', 'RenomarLUsanciér' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Renameuser' => array( 'Renomear_o_usuario', 'Renomear_usuario', 'Renomear_a_usuaria', 'Renomear_usuaria' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'Renameuser' => array( 'Benutzer_e_andre_Name_gee' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Renameuser' => array( 'שינוי_שם_משתמש' ),
);

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = array(
	'Renameuser' => array( 'सदस्यनाम_बदलें', 'सदस्य_नाम_बदलें' ),
);

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = array(
	'Renameuser' => array( 'Preimenuj_suradnika' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'Renameuser' => array( 'Wužiwarja_přemjenować' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Renameuser' => array( 'RenonmenItilizatè' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Renameuser' => array( 'Szerkesztő_átnevezése' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'Renameuser' => array( 'Renominar_usator' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Renameuser' => array( 'Ganti_nama_pengguna', 'GantiNamaPengguna' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'Renameuser' => array( 'RinominaUtente' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Renameuser' => array( '利用者名変更', '利用者名の変更' ),
);

/** Khmer (ភាសាខ្មែរ) */
$specialPageAliases['km'] = array(
	'Renameuser' => array( 'ប្ដូរឈ្មោះអ្នកប្រើប្រាស់' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Renameuser' => array( '이름바꾸기', '사용자이름바꾸기', '계정이름바꾸기' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Renameuser' => array( 'Metmaacher ömnänne', 'Medmaacher ömnänne', 'Metmaacher ömnenne', 'Medmaacher ömnenne', 'Metmaacher ömdäufe', 'Medmaacher ömdäufe' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'Renameuser' => array( 'DashenwelDevnydhyer' ),
);

/** Latin (Latina) */
$specialPageAliases['la'] = array(
	'Renameuser' => array( 'Usorem_renominare' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'Renameuser' => array( 'Benotzer_ëmbenennen' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Renameuser' => array( 'ПреименувајКорисник' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Renameuser' => array( 'ഉപയോക്തൃപുനർനാമകരണം' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'Renameuser' => array( 'सदस्यपुर्नामितकरा' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'Renameuser' => array( 'Tukar_nama_pengguna' ),
);

/** Maltese (Malti) */
$specialPageAliases['mt'] = array(
	'Renameuser' => array( 'BiddelIsemUtent' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'Renameuser' => array( 'Gi_en_bruker_nytt_navn' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'Renameuser' => array( 'Gebruker_herneumen' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'Renameuser' => array( 'GebruikerHernoemen' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'Renameuser' => array( 'Døyp_om_brukar' ),
);

/** Occitan (occitan) */
$specialPageAliases['oc'] = array(
	'Renameuser' => array( 'TornarNomenarUtilizaire', 'Tornar nomenar Utilizaire' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'Renameuser' => array( 'Zmiana_nazwy_użytkownika' ),
);

/** Pashto (پښتو) */
$specialPageAliases['ps'] = array(
	'Renameuser' => array( 'دکارونکي نوم بدلون' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'Renameuser' => array( 'Alterar_nome_de_utilizador' ),
);

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = array(
	'Renameuser' => array( 'Renomear_utilizador', 'Renomear_usuário' ),
);

/** Romanian (română) */
$specialPageAliases['ro'] = array(
	'Renameuser' => array( 'Redenumire_utilizator' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Renameuser' => array( 'Переименовать_участника' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'Renameuser' => array( 'RinominaUtente' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'Renameuser' => array( 'PremenovaťPoužívateľa' ),
);

/** Albanian (shqip) */
$specialPageAliases['sq'] = array(
	'Renameuser' => array( 'RiemërtoPërdorues' ),
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = array(
	'Renameuser' => array( 'ПреименујКорисника', 'Преименуј_корисника' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'Renameuser' => array( 'Användarnamnbyte' ),
);

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = array(
	'Renameuser' => array( 'BadilishajinalaMtumiaji' ),
);

/** Thai (ไทย) */
$specialPageAliases['th'] = array(
	'Renameuser' => array( 'เปลี่ยนชื่อผู้ใช้' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Renameuser' => array( 'Muling_pangalan_ang_tagagamit' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Renameuser' => array( 'KullanıcıAdınıDeğiştir', 'KullanıcıİsminiDeğiştir' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'Renameuser' => array( 'Перейменувати_користувача' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Renameuser' => array( 'Đổi_tên_thành_viên', 'Đổi_tên_người_dùng' ),
);

/** Chinese (中文) */
$specialPageAliases['zh'] = array(
	'Renameuser' => array( '重命名用户', '重新命名用户', '重新命名用戶', '重新命名使用者' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Renameuser' => array( '重命名用户' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Renameuser' => array( '重新命名使用者' ),
);

==> mediawiki-1.27.1-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/Renameuser/Renameuser.alias.php <==
<?php
/**
 * Aliases for Special:Renameuser
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Renameuser' => array( 'RenameUser' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Renameuser' => array( 'إعادة_تسمية_مستخدم' ),
);

/** Egyptian Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Renameuser' => array( 'سمّى_تانى_يوزر' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'Renameuser' => array( 'সদস্য_পুনৰ্নামকৰণ' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'Renameuser' => array( 'Переименовать_участника' ),
);

/** Bashkir (башҡортса) */
$specialPageAliases['ba'] = array(
	'Renameuser' => array( 'RenameUser' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'Renameuser' => array( 'Преименуване' ),
);

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = array(
	'Renameuser' => array( 'کارمرزوکی_نامی_ٹگلینتین' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'Renameuser' => array( 'Ganti_ngaran_pamakai' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'Renameuser' => array( 'AdenevelImplijer' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'Renameuser' => array( 'PreimenovanjeKorisnika' ),
);

/** Catalan (català) */
$specialPageAliases['ca'] = array(
	'Renameuser' => array( 'Reanomena_usuari' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Renameuser' => array( 'Декъашхочун_цӀе_хийца' ),
);

/** Czech (čeština) */
$specialPageAliases['cs'] = array(
	'Renameuser' => array( 'Přejmenovat_uživatele' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Renameuser' => array( 'Benutzer_umbenennen' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Renameuser' => array( 'NamedayışéKarberi' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'Renameuser' => array( 'Wužywarja pśemjeniś' ),
);

/** Divehi (ދިވެހިބަސް) */
$specialPageAliases['dv'] = array(
	'Renameuser' => array( 'މެމްބަރުގެ_ނަން_ބަދަލު_ކުރައްވާ' ),
);

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = array(
	'Renameuser' => array( 'ΜετονομασίαΧρήστη' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Renameuser' => array( 'Alinomigi_uzanton' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Renameuser' => array( 'RenombrarUsuario', 'Renombrar_usuario', 'Cambiar_el_nombre_de_usuario' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Renameuser' => array( 'Kasutaja_ümbernimetamine' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Renameuser' => array( 'تغییر_نام_کاربر' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Renameuser' => array( 'Käyttäjätunnusten_nimeäminen' ),
);

/** French (français) */
$specialPageAliases['fr'] = array(
	'Renameuser' => array( 'Renommer_utilisateur', 'RenommerUtilisateur' ),
);

/** Arpitan (arpetan) */
$specialPageAliases['frp'] = array(
	'Renameuser' => array( 'Renomar_l\'usanciér', 'RenomarLUsanciér' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Renameuser' => array( 'Renomear_o_usuario', 'Renomear_usuario', 'Renomear_a_usuaria', 'Renomear_usuaria' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'Renameuser' => array( 'Benutzer_e_andre_Name_gee' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Renameuser' => array( 'שינוי_שם_משתמש' ),
);

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = array(
	'Renameuser' => array( 'सदस्यनाम_बदलें', 'सदस्य_नाम_बदलें' ),
);

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = array(
	'Renameuser' => array( 'Preimenuj_suradnika' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'Renameuser' => array( 'Wužiwarja_přemjenować' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Renameuser' => array( 'RenonmenItilizatè' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Renameuser' => array( 'Szerkesztő_átnevezése' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'Renameuser' => array( 'Renominar_usator' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Renameuser' => array( 'Ganti_nama_pengguna', 'GantiNamaPengguna' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'Renameuser' => array( 'RinominaUtente' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Renameuser' => array( '利用者名変更', '利用者名の変更' ),
);

/** Khmer (ភាសាខ្មែរ) */
$specialPageAliases['km'] = array(
	'Renameuser' => array( 'ប្ដូរឈ្មោះអ្នកប្រើប្រាស់' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Renameuser' => array( '이름바꾸기', '사용자이름바꾸기', '계정이름바꾸기' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Renameuser' => array( 'Metmaacher ömnänne', 'Medmaacher ömnänne', 'Metmaacher ömnenne', 'Medmaacher ömnenne', 'Metmaacher ömdäufe', 'Medmaacher ömdäufe' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'Renameuser' => array( 'DashenwelDevnydhyer' ),
);

/** Latin (Latina) */
$specialPageAliases['la'] = array(
	'Renameuser' => array( 'Usorem_renominare' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'Renameuser' => array( 'Benotzer_ëmbenennen' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Renameuser' => array( 'ПреименувајКорисник' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Renameuser' => array( 'ഉപയോക്തൃപുനർനാമകരണം' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'Renameuser' => array( 'सदस्यपुर्नामितकरा' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'Renameuser' => array( 'Tukar_nama_pengguna' ),
);

/** Maltese (Malti) */
$specialPageAliases['mt'] = array(
	'Renameuser' => array( 'BiddelIsemUtent' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'Renameuser' => array( 'Gi_en_bruker_nytt_navn' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'Renameuser' => array( 'Gebruker_herneumen' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'Renameuser' => array( 'GebruikerHernoemen' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'Renameuser' => array( 'Døyp_om_brukar' ),
);

/** Occitan (occitan) */
$specialPageAliases['oc'] = array(
	'Renameuser' => array( 'TornarNomenarUtilizaire', 'Tornar nomenar Utilizaire' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'Renameuser' => array( 'Zmiana_nazwy_użytkownika' ),
);

/** Pashto (پښتو) */
$specialPageAliases['ps'] = array(
	'Renameuser' => array( 'دکارونکي نوم بدلون' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'Renameuser' => array( 'Alterar_nome_de_utilizador' ),
);

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = array(
	'Renameuser' => array( 'Renomear_utilizador', 'Renomear_usuário' ),
);

/** Romanian (română) */
$specialPageAliases['ro'] = array(
	'Renameuser' => array( 'Redenumire_utilizator' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Renameuser' => array( 'Переименовать_участника' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'Renameuser' => array( 'RinominaUtente' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'Renameuser' => array( 'PremenovaťPoužívateľa' ),
);

/** Albanian (shqip) */
$specialPageAliases['sq'] = array(
	'Renameuser' => array( 'RiemërtoPërdorues' ),
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = array(
	'Renameuser' => array( 'ПреименујКорисника', 'Преименуј_корисника' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'Renameuser' => array( 'Användarnamnbyte' ),
);

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = array(
	'Renameuser' => array( 'BadilishajinalaMtumiaji' ),
);

/** Thai (ไทย) */
$specialPageAliases['th'] = array(
	'Renameuser' => array( 'เปลี่ยนชื่อผู้ใช้' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Renameuser' => array( 'Muling_pangalan_ang_tagagamit' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Renameuser' => array( 'KullanıcıAdınıDeğiştir', 'KullanıcıİsminiDeğiştir' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'Renameuser' => array( 'Перейменувати_користувача' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Renameuser' => array( 'Đổi_tên_thành_viên', 'Đổi_tên_người_dùng' ),
);

/** Chinese (中文) */
$specialPageAliases['zh'] = array(
	'Renameuser' => array( '重命名用户', '重新命名用户', '重新命名用戶', '重新命名使用者' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Renameuser' => array( '重命名用户' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Renameuser' => array( '重新命名使用者' ),
);
